// Copyright 2009 the Sputnik authors.  All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

/*---
info: |
    String.prototype.search (regexp) without arguments behaves like with
    argument "undefined"
es5id: 15.5.4.12_A1.1_T1
description: Call search() is the same search(undefined)
---*/

//////////////////////////////////////////////////////////////////////////////
//CHECK#1
var x = "".search();
//
//////////////////////////////////////////////////////////////////////////////
